Answer - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Answer

class inmydata.ConversationalData.Answer(answer: str, subject: str)

  Bases: `object`

  A data class for providing a string response to a question.

  answer

    The string response to the question.

    Type:

      str

  subject

    The subject of the question, which can be used to generate the answer.

    Type:

      str

  answer: str
  subject: str